# -*- coding: utf-8 -*-

"""
Copyright 2021 The Dapr Authors
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
    http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from datetime import timedelta
from typing import Any, Dict, List, Optional, Set


class ActorReentrancyConfig:
    def __init__(
            self,
            enabled: bool = False,
            maxStackDepth: int = 32):
        """Inits :class:`ActorReentrancyConfig` to optionally configure actor
        reentrancy.

        Args:
            enabled (bool): Set to enable or disable reentrancy.
            maxStackDepth (int): Limit for the number of concurrent reentrant requests
                to an actor, further requests are denied.
        """

        self._enabled = enabled
        self._maxStackDepth = maxStackDepth

    def as_dict(self) -> Dict[str, Any]:
        """Returns ActorReentrancyConfig as a dict."""
        return {
            'enabled': self._enabled,
            'maxStackDepth': self._maxStackDepth,
        }


class ActorTypeConfig:
    """Per Actor Type Configuration that configures Actor behavior for a specific Actor Type in
    Dapr Runtime.
    """

    def __init__(
            self,
            actor_type: str,
            actor_idle_timeout: Optional[timedelta] = None,
            actor_scan_interval: Optional[timedelta] = None,
            drain_ongoing_call_timeout: Optional[timedelta] = None,
            drain_rebalanced_actors: Optional[bool] = None,
            reentrancy: Optional[ActorReentrancyConfig] = None,
            reminders_storage_partitions: Optional[int] = None):
        """Inits :class:`ActorTypeConfig` to configure the behavior of a specific actor type
        when dapr runtime starts.

        Args:
            actor_type (str): Actor type.
            actor_idle_timeout (datetime.timedelta): The timeout before deactivating an idle actor.
            actor_scan_interval (datetime.timedelta): The duration which specifies how often to scan
                for actors to deactivate idle actors. Actors that have been idle longer than
                actor_idle_timeout will be deactivated.
            drain_ongoing_call_timeout (datetime.timedelta): The duration which specifies the
                timeout for the current active actor method to finish before actor deactivation.
                If there is no current actor method call, this is ignored.
            drain_rebalanced_actors (bool): If true, Dapr will wait for drain_ongoing_call_timeout
                to allow a current actor call to complete before trying to deactivate an actor.
            reentrancy (ActorReentrancyConfig): Configure the reentrancy behavior for an actor.
                If not provided, reentrancy is diabled.
            reminders_storage_partitions (int): The number of partitions to use for reminders
                storage.
        """
        self._actor_type = actor_type
        self._actor_idle_timeout = actor_idle_timeout
        self._actor_scan_interval = actor_scan_interval
        self._drain_ongoing_call_timeout = drain_ongoing_call_timeout
        self._drain_rebalanced_actors = drain_rebalanced_actors
        self._reentrancy = reentrancy
        self._reminders_storage_partitions = reminders_storage_partitions

    def as_dict(self) -> Dict[str, Any]:
        """Returns ActorTypeConfig as a dict."""

        configDict: Dict[str, Any] = dict()
        configDict['entities'] = [self._actor_type]

        if self._actor_idle_timeout is not None:
            configDict.update({'actorIdleTimeout': self._actor_idle_timeout})

        if self._actor_scan_interval is not None:
            configDict.update({'actorScanInterval': self._actor_scan_interval})

        if self._drain_ongoing_call_timeout is not None:
            configDict.update({'drainOngoingCallTimeout': self._drain_ongoing_call_timeout})

        if self._drain_rebalanced_actors is not None:
            configDict.update({'drainRebalancedActors': self._drain_rebalanced_actors})

        if self._reentrancy:
            configDict.update({'reentrancy': self._reentrancy.as_dict()})

        if self._reminders_storage_partitions:
            configDict.update(
                {'remindersStoragePartitions': self._reminders_storage_partitions})

        return configDict


class ActorRuntimeConfig:
    """Actor runtime configuration that configures Actor behavior in
    Dapr Runtime.
    """

    def __init__(
            self,
            actor_idle_timeout: Optional[timedelta] = timedelta(hours=1),
            actor_scan_interval: Optional[timedelta] = timedelta(seconds=30),
            drain_ongoing_call_timeout: Optional[timedelta] = timedelta(minutes=1),
            drain_rebalanced_actors: Optional[bool] = True,
            reentrancy: Optional[ActorReentrancyConfig] = None,
            reminders_storage_partitions: Optional[int] = None,
            actor_type_configs: List[ActorTypeConfig] = []):
        """Inits :class:`ActorRuntimeConfig` to configure actors when dapr runtime starts.

        Args:
            actor_idle_timeout (datetime.timedelta): The timeout before deactivating an idle actor.
            actor_scan_interval (datetime.timedelta): The duration which specifies how often to scan
                for actors to deactivate idle actors. Actors that have been idle longer than
                actor_idle_timeout will be deactivated.
            drain_ongoing_call_timeout (datetime.timedelta): The duration which specifies the
                timeout for the current active actor method to finish before actor deactivation.
                If there is no current actor method call, this is ignored.
            drain_rebalanced_actors (bool): If true, Dapr will wait for drain_ongoing_call_timeout
                to allow a current actor call to complete before trying to deactivate an actor.
            reentrancy (ActorReentrancyConfig): Configure the reentrancy behavior for an actor.
                If not provided, reentrancy is diabled.
            reminders_storage_partitions (int): The number of partitions to use for reminders
                storage.
            actor_type_configs (List[ActorTypeConfig]): Configure the behavior of specific
                actor types.
        """
        self._entities: Set[str] = set()
        self._actor_idle_timeout = actor_idle_timeout
        self._actor_scan_interval = actor_scan_interval
        self._drain_ongoing_call_timeout = drain_ongoing_call_timeout
        self._drain_rebalanced_actors = drain_rebalanced_actors
        self._reentrancy = reentrancy
        self._reminders_storage_partitions = reminders_storage_partitions
        self._entitiesConfig: List[ActorTypeConfig] = actor_type_configs

    def update_entities(self, entities: List[str]) -> None:
        """Updates actor types in entities property.

        Args:
            entities (List[str]): the list of actor type names
        """
        self._entities.update(entities)

    def update_actor_type_configs(self, actor_type_configs: List[ActorTypeConfig]) -> None:
        """Updates actor type configs.

        Args:
            actor_type_configs (List[ActorTypeConfig]): the list of actor type configs
        """
        self._entitiesConfig = actor_type_configs or []

    def as_dict(self) -> Dict[str, Any]:
        """Returns ActorRuntimeConfig as a dict."""

        entities: Set[str] = self._entities

        configDict: Dict[str, Any] = {
            'actorIdleTimeout': self._actor_idle_timeout,
            'actorScanInterval': self._actor_scan_interval,
            'drainOngoingCallTimeout': self._drain_ongoing_call_timeout,
            'drainRebalancedActors': self._drain_rebalanced_actors,
        }

        if self._reentrancy:
            configDict.update({'reentrancy': self._reentrancy.as_dict()})

        if self._reminders_storage_partitions:
            configDict.update(
                {'remindersStoragePartitions': self._reminders_storage_partitions})

        configDict['entitiesConfig'] = []
        for entityConfig in self._entitiesConfig:
            configDict['entitiesConfig'].append(entityConfig.as_dict())
            entities.add(entityConfig._actor_type)

        configDict['entities'] = list(entities)

        return configDict



# -*- coding: utf-8 -*-

"""
Copyright 2021 The Dapr Authors
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
    http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

import asyncio
import uuid

from typing import Any, Callable, Coroutine, Dict, Optional

from dapr.actor.id import ActorId
from dapr.clients.exceptions import DaprInternalError
from dapr.actor.runtime.actor import Actor
from dapr.actor.runtime.context import ActorRuntimeContext
from dapr.actor.runtime._method_context import ActorMethodContext
from dapr.actor.runtime.method_dispatcher import ActorMethodDispatcher
from dapr.actor.runtime._reminder_data import ActorReminderData
from dapr.actor.runtime.reentrancy_context import reentrancy_ctx

TIMER_METHOD_NAME = 'fire_timer'
REMINDER_METHOD_NAME = 'receive_reminder'


class ActorManager:
    """A Actor Manager manages actors of a specific actor type."""

    def __init__(self, ctx: ActorRuntimeContext):
        self._runtime_ctx = ctx
        self._message_serializer = self._runtime_ctx.message_serializer

        self._active_actors: Dict[str, Actor] = {}
        self._active_actors_lock = asyncio.Lock()

        self._dispatcher = ActorMethodDispatcher(ctx.actor_type_info)
        self._timer_method_context = ActorMethodContext.create_for_timer(TIMER_METHOD_NAME)
        self._reminder_method_context = ActorMethodContext.create_for_reminder(REMINDER_METHOD_NAME)

    async def activate_actor(self, actor_id: ActorId):
        """Activates actor."""
        actor = self._runtime_ctx.create_actor(actor_id)
        await actor._on_activate_internal()

        async with self._active_actors_lock:
            self._active_actors[actor_id.id] = actor

    async def deactivate_actor(self, actor_id: ActorId):
        async with self._active_actors_lock:
            deactivated_actor = self._active_actors.pop(actor_id.id, None)
            if not deactivated_actor:
                raise ValueError(f'{actor_id} is not activated')
        await deactivated_actor._on_deactivate_internal()

    async def fire_reminder(
            self, actor_id: ActorId,
            reminder_name: str, request_body: bytes) -> None:
        if not self._runtime_ctx.actor_type_info.is_remindable():
            raise ValueError(
                f'{self._runtime_ctx.actor_type_info.type_name} does not implment Remindable.')
        request_obj = self._message_serializer.deserialize(request_body, object)
        if isinstance(request_obj, dict):
            reminder_data = ActorReminderData.from_dict(reminder_name, request_obj)
        # ignore if request_obj is not dict

        async def invoke_reminder(actor: Actor) -> Optional[bytes]:
            reminder = getattr(actor, REMINDER_METHOD_NAME)
            if reminder is not None:
                await reminder(reminder_data.reminder_name, reminder_data.state,
                               reminder_data.due_time, reminder_data.period, reminder_data.ttl)
            return None

        await self._dispatch_internal(actor_id, self._reminder_method_context, invoke_reminder)

    async def fire_timer(
            self, actor_id: ActorId,
            timer_name: str, request_body: bytes) -> None:
        timer = self._message_serializer.deserialize(request_body, object)

        async def invoke_timer(actor: Actor) -> Optional[bytes]:
            await actor._fire_timer_internal(timer['callback'], timer['data'])
            return None

        await self._dispatch_internal(actor_id, self._timer_method_context, invoke_timer)

    async def dispatch(
            self, actor_id: ActorId,
            actor_method_name: str, request_body: bytes) -> bytes:
        method_context = ActorMethodContext.create_for_actor(actor_method_name)
        arg_types = self._dispatcher.get_arg_types(actor_method_name)

        async def invoke_method(actor):
            if len(arg_types) > 0:
                # Limitation:
                # * Support only one argument
                # * If you use the default DaprJSONSerializer, it support only object type
                # as a argument
                input_obj = self._message_serializer.deserialize(request_body, arg_types[0])
                rtnval = await self._dispatcher.dispatch(actor, actor_method_name, input_obj)
            else:
                rtnval = await self._dispatcher.dispatch(actor, actor_method_name)
            return rtnval

        rtn_obj = await self._dispatch_internal(actor_id, method_context, invoke_method)
        return self._message_serializer.serialize(rtn_obj)

    async def _dispatch_internal(
            self, actor_id: ActorId, method_context: ActorMethodContext,
            dispatch_action: Callable[[Actor], Coroutine[Any, Any, Optional[bytes]]]) -> object:
        # Activate actor when actor is invoked.
        if actor_id.id not in self._active_actors:
            await self.activate_actor(actor_id)
        actor = None
        async with self._active_actors_lock:
            actor = self._active_actors.get(actor_id.id, None)
        if not actor:
            raise ValueError(f'{actor_id} is not activated')

        try:
            if reentrancy_ctx.get(None) is not None:
                actor._state_manager.set_state_context(str(uuid.uuid4()))
            await actor._on_pre_actor_method_internal(method_context)
            retval = await dispatch_action(actor)
            await actor._on_post_actor_method_internal(method_context)
        except DaprInternalError as ex:
            await actor._on_invoke_failed_internal(ex)
            raise ex
        finally:
            if reentrancy_ctx is not None:
                actor._state_manager.set_state_context(None)

        return retval



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from dapr.proto.common.v1 import common_pb2 as dapr_dot_proto_dot_common_dot_v1_dot_common__pb2
from dapr.proto.runtime.v1 import dapr_pb2 as dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class DaprStub(object):
    """Dapr service provides APIs to user application to access Dapr building blocks.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.InvokeService = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/InvokeService',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.InvokeServiceRequest.SerializeToString,
                response_deserializer=dapr_dot_proto_dot_common_dot_v1_dot_common__pb2.InvokeResponse.FromString,
                )
        self.GetState = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/GetState',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetStateRequest.SerializeToString,
                response_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetStateResponse.FromString,
                )
        self.GetBulkState = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/GetBulkState',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetBulkStateRequest.SerializeToString,
                response_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetBulkStateResponse.FromString,
                )
        self.SaveState = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/SaveState',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.SaveStateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.QueryStateAlpha1 = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/QueryStateAlpha1',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.QueryStateRequest.SerializeToString,
                response_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.QueryStateResponse.FromString,
                )
        self.DeleteState = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/DeleteState',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.DeleteStateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteBulkState = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/DeleteBulkState',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.DeleteBulkStateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ExecuteStateTransaction = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/ExecuteStateTransaction',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.ExecuteStateTransactionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.PublishEvent = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/PublishEvent',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.PublishEventRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.InvokeBinding = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/InvokeBinding',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.InvokeBindingRequest.SerializeToString,
                response_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.InvokeBindingResponse.FromString,
                )
        self.GetSecret = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/GetSecret',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetSecretRequest.SerializeToString,
                response_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetSecretResponse.FromString,
                )
        self.GetBulkSecret = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/GetBulkSecret',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetBulkSecretRequest.SerializeToString,
                response_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetBulkSecretResponse.FromString,
                )
        self.RegisterActorTimer = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/RegisterActorTimer',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.RegisterActorTimerRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UnregisterActorTimer = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/UnregisterActorTimer',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.UnregisterActorTimerRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RegisterActorReminder = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/RegisterActorReminder',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.RegisterActorReminderRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UnregisterActorReminder = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/UnregisterActorReminder',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.UnregisterActorReminderRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RenameActorReminder = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/RenameActorReminder',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.RenameActorReminderRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetActorState = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/GetActorState',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetActorStateRequest.SerializeToString,
                response_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetActorStateResponse.FromString,
                )
        self.ExecuteActorStateTransaction = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/ExecuteActorStateTransaction',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.ExecuteActorStateTransactionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.InvokeActor = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/InvokeActor',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.InvokeActorRequest.SerializeToString,
                response_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.InvokeActorResponse.FromString,
                )
        self.GetConfigurationAlpha1 = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/GetConfigurationAlpha1',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetConfigurationRequest.SerializeToString,
                response_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetConfigurationResponse.FromString,
                )
        self.SubscribeConfigurationAlpha1 = channel.unary_stream(
                '/dapr.proto.runtime.v1.Dapr/SubscribeConfigurationAlpha1',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.SubscribeConfigurationRequest.SerializeToString,
                response_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.SubscribeConfigurationResponse.FromString,
                )
        self.UnsubscribeConfigurationAlpha1 = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/UnsubscribeConfigurationAlpha1',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.UnsubscribeConfigurationRequest.SerializeToString,
                response_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.UnsubscribeConfigurationResponse.FromString,
                )
        self.TryLockAlpha1 = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/TryLockAlpha1',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.TryLockRequest.SerializeToString,
                response_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.TryLockResponse.FromString,
                )
        self.UnlockAlpha1 = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/UnlockAlpha1',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.UnlockRequest.SerializeToString,
                response_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.UnlockResponse.FromString,
                )
        self.GetMetadata = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/GetMetadata',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetMetadataResponse.FromString,
                )
        self.SetMetadata = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/SetMetadata',
                request_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.SetMetadataRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.Shutdown = channel.unary_unary(
                '/dapr.proto.runtime.v1.Dapr/Shutdown',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class DaprServicer(object):
    """Dapr service provides APIs to user application to access Dapr building blocks.
    """

    def InvokeService(self, request, context):
        """Invokes a method on a remote Dapr app.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetState(self, request, context):
        """Gets the state for a specific key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBulkState(self, request, context):
        """Gets a bulk of state items for a list of keys
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SaveState(self, request, context):
        """Saves the state for a specific key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryStateAlpha1(self, request, context):
        """Queries the state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteState(self, request, context):
        """Deletes the state for a specific key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteBulkState(self, request, context):
        """Deletes a bulk of state items for a list of keys
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteStateTransaction(self, request, context):
        """Executes transactions for a specified store
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PublishEvent(self, request, context):
        """Publishes events to the specific topic.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InvokeBinding(self, request, context):
        """Invokes binding data to specific output bindings
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSecret(self, request, context):
        """Gets secrets from secret stores.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBulkSecret(self, request, context):
        """Gets a bulk of secrets
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterActorTimer(self, request, context):
        """Register an actor timer.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnregisterActorTimer(self, request, context):
        """Unregister an actor timer.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterActorReminder(self, request, context):
        """Register an actor reminder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnregisterActorReminder(self, request, context):
        """Unregister an actor reminder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RenameActorReminder(self, request, context):
        """Rename an actor reminder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetActorState(self, request, context):
        """Gets the state for a specific actor.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteActorStateTransaction(self, request, context):
        """Executes state transactions for a specified actor
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InvokeActor(self, request, context):
        """InvokeActor calls a method on an actor.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConfigurationAlpha1(self, request, context):
        """GetConfiguration gets configuration from configuration store.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubscribeConfigurationAlpha1(self, request, context):
        """SubscribeConfiguration gets configuration from configuration store and subscribe the updates event by grpc stream
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnsubscribeConfigurationAlpha1(self, request, context):
        """UnSubscribeConfiguration unsubscribe the subscription of configuration
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TryLockAlpha1(self, request, context):
        """TryLockAlpha1 tries to get a lock with an expiry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnlockAlpha1(self, request, context):
        """UnlockAlpha1 unlocks a lock.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMetadata(self, request, context):
        """Gets metadata of the sidecar
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetMetadata(self, request, context):
        """Sets value in extended metadata of the sidecar
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Shutdown(self, request, context):
        """Shutdown the sidecar
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DaprServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'InvokeService': grpc.unary_unary_rpc_method_handler(
                    servicer.InvokeService,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.InvokeServiceRequest.FromString,
                    response_serializer=dapr_dot_proto_dot_common_dot_v1_dot_common__pb2.InvokeResponse.SerializeToString,
            ),
            'GetState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetState,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetStateRequest.FromString,
                    response_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetStateResponse.SerializeToString,
            ),
            'GetBulkState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBulkState,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetBulkStateRequest.FromString,
                    response_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetBulkStateResponse.SerializeToString,
            ),
            'SaveState': grpc.unary_unary_rpc_method_handler(
                    servicer.SaveState,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.SaveStateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'QueryStateAlpha1': grpc.unary_unary_rpc_method_handler(
                    servicer.QueryStateAlpha1,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.QueryStateRequest.FromString,
                    response_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.QueryStateResponse.SerializeToString,
            ),
            'DeleteState': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteState,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.DeleteStateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteBulkState': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteBulkState,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.DeleteBulkStateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ExecuteStateTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.ExecuteStateTransaction,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.ExecuteStateTransactionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'PublishEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.PublishEvent,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.PublishEventRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'InvokeBinding': grpc.unary_unary_rpc_method_handler(
                    servicer.InvokeBinding,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.InvokeBindingRequest.FromString,
                    response_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.InvokeBindingResponse.SerializeToString,
            ),
            'GetSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSecret,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetSecretRequest.FromString,
                    response_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetSecretResponse.SerializeToString,
            ),
            'GetBulkSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBulkSecret,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetBulkSecretRequest.FromString,
                    response_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetBulkSecretResponse.SerializeToString,
            ),
            'RegisterActorTimer': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterActorTimer,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.RegisterActorTimerRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UnregisterActorTimer': grpc.unary_unary_rpc_method_handler(
                    servicer.UnregisterActorTimer,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.UnregisterActorTimerRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RegisterActorReminder': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterActorReminder,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.RegisterActorReminderRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UnregisterActorReminder': grpc.unary_unary_rpc_method_handler(
                    servicer.UnregisterActorReminder,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.UnregisterActorReminderRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RenameActorReminder': grpc.unary_unary_rpc_method_handler(
                    servicer.RenameActorReminder,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.RenameActorReminderRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetActorState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetActorState,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetActorStateRequest.FromString,
                    response_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetActorStateResponse.SerializeToString,
            ),
            'ExecuteActorStateTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.ExecuteActorStateTransaction,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.ExecuteActorStateTransactionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'InvokeActor': grpc.unary_unary_rpc_method_handler(
                    servicer.InvokeActor,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.InvokeActorRequest.FromString,
                    response_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.InvokeActorResponse.SerializeToString,
            ),
            'GetConfigurationAlpha1': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConfigurationAlpha1,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetConfigurationRequest.FromString,
                    response_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetConfigurationResponse.SerializeToString,
            ),
            'SubscribeConfigurationAlpha1': grpc.unary_stream_rpc_method_handler(
                    servicer.SubscribeConfigurationAlpha1,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.SubscribeConfigurationRequest.FromString,
                    response_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.SubscribeConfigurationResponse.SerializeToString,
            ),
            'UnsubscribeConfigurationAlpha1': grpc.unary_unary_rpc_method_handler(
                    servicer.UnsubscribeConfigurationAlpha1,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.UnsubscribeConfigurationRequest.FromString,
                    response_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.UnsubscribeConfigurationResponse.SerializeToString,
            ),
            'TryLockAlpha1': grpc.unary_unary_rpc_method_handler(
                    servicer.TryLockAlpha1,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.TryLockRequest.FromString,
                    response_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.TryLockResponse.SerializeToString,
            ),
            'UnlockAlpha1': grpc.unary_unary_rpc_method_handler(
                    servicer.UnlockAlpha1,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.UnlockRequest.FromString,
                    response_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.UnlockResponse.SerializeToString,
            ),
            'GetMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMetadata,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetMetadataResponse.SerializeToString,
            ),
            'SetMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.SetMetadata,
                    request_deserializer=dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.SetMetadataRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'Shutdown': grpc.unary_unary_rpc_method_handler(
                    servicer.Shutdown,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dapr.proto.runtime.v1.Dapr', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Dapr(object):
    """Dapr service provides APIs to user application to access Dapr building blocks.
    """

    @staticmethod
    def InvokeService(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/InvokeService',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.InvokeServiceRequest.SerializeToString,
            dapr_dot_proto_dot_common_dot_v1_dot_common__pb2.InvokeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/GetState',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetStateRequest.SerializeToString,
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBulkState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/GetBulkState',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetBulkStateRequest.SerializeToString,
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetBulkStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SaveState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/SaveState',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.SaveStateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryStateAlpha1(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/QueryStateAlpha1',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.QueryStateRequest.SerializeToString,
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.QueryStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/DeleteState',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.DeleteStateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteBulkState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/DeleteBulkState',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.DeleteBulkStateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExecuteStateTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/ExecuteStateTransaction',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.ExecuteStateTransactionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PublishEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/PublishEvent',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.PublishEventRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InvokeBinding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/InvokeBinding',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.InvokeBindingRequest.SerializeToString,
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.InvokeBindingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/GetSecret',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetSecretRequest.SerializeToString,
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBulkSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/GetBulkSecret',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetBulkSecretRequest.SerializeToString,
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetBulkSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterActorTimer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/RegisterActorTimer',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.RegisterActorTimerRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnregisterActorTimer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/UnregisterActorTimer',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.UnregisterActorTimerRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterActorReminder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/RegisterActorReminder',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.RegisterActorReminderRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnregisterActorReminder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/UnregisterActorReminder',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.UnregisterActorReminderRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RenameActorReminder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/RenameActorReminder',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.RenameActorReminderRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetActorState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/GetActorState',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetActorStateRequest.SerializeToString,
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetActorStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExecuteActorStateTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/ExecuteActorStateTransaction',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.ExecuteActorStateTransactionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InvokeActor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/InvokeActor',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.InvokeActorRequest.SerializeToString,
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.InvokeActorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetConfigurationAlpha1(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/GetConfigurationAlpha1',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetConfigurationRequest.SerializeToString,
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetConfigurationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubscribeConfigurationAlpha1(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/dapr.proto.runtime.v1.Dapr/SubscribeConfigurationAlpha1',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.SubscribeConfigurationRequest.SerializeToString,
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.SubscribeConfigurationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnsubscribeConfigurationAlpha1(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/UnsubscribeConfigurationAlpha1',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.UnsubscribeConfigurationRequest.SerializeToString,
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.UnsubscribeConfigurationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TryLockAlpha1(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/TryLockAlpha1',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.TryLockRequest.SerializeToString,
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.TryLockResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnlockAlpha1(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/UnlockAlpha1',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.UnlockRequest.SerializeToString,
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.UnlockResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/GetMetadata',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.GetMetadataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/SetMetadata',
            dapr_dot_proto_dot_runtime_dot_v1_dot_dapr__pb2.SetMetadataRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Shutdown(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dapr.proto.runtime.v1.Dapr/Shutdown',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-

"""
Copyright 2021 The Dapr Authors
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
    http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from abc import ABC


class ActorInterface(ABC):
    """A base class that Dapr Actor inherits.

    Actor requires to inherit ActorInterface as a base class.

    Example::

        class DaprActorInterface(ActorInterface):
            @actormethod('DoActorMethod1')
            async def do_actor_method1(self, param):
                ...

            @actormethod('DoActorMethod2')
            async def do_actor_method2(self, param):
                ...
    """
    ...


def actormethod(name: str = None):
    """Decorate actor method to define the method invoked by the remote actor.

    This allows users to call the decorated name via the proxy client.

    Example::

        class DaprActorInterface(ActorInterface):
            @actormethod(name='DoActorCall')
            async def do_actor_call(self, param):
                ...

    Args:
        name (str): the name of actor method.
    """
    def wrapper(funcobj):
        funcobj.__actormethod__ = name
        funcobj.__isabstractmethod__ = True
        return funcobj
    return wrapper



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dapr/proto/runtime/v1/dapr.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from dapr.proto.common.v1 import common_pb2 as dapr_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n dapr/proto/runtime/v1/dapr.proto\x12\x15\x64\x61pr.proto.runtime.v1\x1a\x19google/protobuf/any.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a!dapr/proto/common/v1/common.proto\"X\n\x14InvokeServiceRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x07message\x18\x03 \x01(\x0b\x32#.dapr.proto.common.v1.InvokeRequest\"\xf5\x01\n\x0fGetStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12H\n\x0b\x63onsistency\x18\x03 \x01(\x0e\x32\x33.dapr.proto.common.v1.StateOptions.StateConsistency\x12\x46\n\x08metadata\x18\x04 \x03(\x0b\x32\x34.dapr.proto.runtime.v1.GetStateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc9\x01\n\x13GetBulkStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x13\n\x0bparallelism\x18\x03 \x01(\x05\x12J\n\x08metadata\x18\x04 \x03(\x0b\x32\x38.dapr.proto.runtime.v1.GetBulkStateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"K\n\x14GetBulkStateResponse\x12\x33\n\x05items\x18\x01 \x03(\x0b\x32$.dapr.proto.runtime.v1.BulkStateItem\"\xbe\x01\n\rBulkStateItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\x12\x44\n\x08metadata\x18\x05 \x03(\x0b\x32\x32.dapr.proto.runtime.v1.BulkStateItem.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa8\x01\n\x10GetStateResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12G\n\x08metadata\x18\x03 \x03(\x0b\x32\x35.dapr.proto.runtime.v1.GetStateResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x90\x02\n\x12\x44\x65leteStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12(\n\x04\x65tag\x18\x03 \x01(\x0b\x32\x1a.dapr.proto.common.v1.Etag\x12\x33\n\x07options\x18\x04 \x01(\x0b\x32\".dapr.proto.common.v1.StateOptions\x12I\n\x08metadata\x18\x05 \x03(\x0b\x32\x37.dapr.proto.runtime.v1.DeleteStateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n\x16\x44\x65leteBulkStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12/\n\x06states\x18\x02 \x03(\x0b\x32\x1f.dapr.proto.common.v1.StateItem\"W\n\x10SaveStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12/\n\x06states\x18\x02 \x03(\x0b\x32\x1f.dapr.proto.common.v1.StateItem\"\xb1\x01\n\x11QueryStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12H\n\x08metadata\x18\x03 \x03(\x0b\x32\x36.dapr.proto.runtime.v1.QueryStateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x0eQueryStateItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"\xd7\x01\n\x12QueryStateResponse\x12\x36\n\x07results\x18\x01 \x03(\x0b\x32%.dapr.proto.runtime.v1.QueryStateItem\x12\r\n\x05token\x18\x02 \x01(\t\x12I\n\x08metadata\x18\x03 \x03(\x0b\x32\x37.dapr.proto.runtime.v1.QueryStateResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdf\x01\n\x13PublishEventRequest\x12\x13\n\x0bpubsub_name\x18\x01 \x01(\t\x12\r\n\x05topic\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x19\n\x11\x64\x61ta_content_type\x18\x04 \x01(\t\x12J\n\x08metadata\x18\x05 \x03(\x0b\x32\x38.dapr.proto.runtime.v1.PublishEventRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc3\x01\n\x14InvokeBindingRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12K\n\x08metadata\x18\x03 \x03(\x0b\x32\x39.dapr.proto.runtime.v1.InvokeBindingRequest.MetadataEntry\x12\x11\n\toperation\x18\x04 \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa4\x01\n\x15InvokeBindingResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12L\n\x08metadata\x18\x02 \x03(\x0b\x32:.dapr.proto.runtime.v1.InvokeBindingResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xad\x01\n\x10GetSecretRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12G\n\x08metadata\x18\x03 \x03(\x0b\x32\x35.dapr.proto.runtime.v1.GetSecretRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x82\x01\n\x11GetSecretResponse\x12@\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x32.dapr.proto.runtime.v1.GetSecretResponse.DataEntry\x1a+\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa8\x01\n\x14GetBulkSecretRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12K\n\x08metadata\x18\x02 \x03(\x0b\x32\x39.dapr.proto.runtime.v1.GetBulkSecretRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x85\x01\n\x0eSecretResponse\x12\x43\n\x07secrets\x18\x01 \x03(\x0b\x32\x32.dapr.proto.runtime.v1.SecretResponse.SecretsEntry\x1a.\n\x0cSecretsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb1\x01\n\x15GetBulkSecretResponse\x12\x44\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x36.dapr.proto.runtime.v1.GetBulkSecretResponse.DataEntry\x1aR\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.dapr.proto.runtime.v1.SecretResponse:\x02\x38\x01\"f\n\x1bTransactionalStateOperation\x12\x15\n\roperationType\x18\x01 \x01(\t\x12\x30\n\x07request\x18\x02 \x01(\x0b\x32\x1f.dapr.proto.common.v1.StateItem\"\x83\x02\n\x1e\x45xecuteStateTransactionRequest\x12\x11\n\tstoreName\x18\x01 \x01(\t\x12\x46\n\noperations\x18\x02 \x03(\x0b\x32\x32.dapr.proto.runtime.v1.TransactionalStateOperation\x12U\n\x08metadata\x18\x03 \x03(\x0b\x32\x43.dapr.proto.runtime.v1.ExecuteStateTransactionRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9e\x01\n\x19RegisterActorTimerRequest\x12\x12\n\nactor_type\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tor_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08\x64ue_time\x18\x04 \x01(\t\x12\x0e\n\x06period\x18\x05 \x01(\t\x12\x10\n\x08\x63\x61llback\x18\x06 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x07 \x01(\x0c\x12\x0b\n\x03ttl\x18\x08 \x01(\t\"Q\n\x1bUnregisterActorTimerRequest\x12\x12\n\nactor_type\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tor_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x8f\x01\n\x1cRegisterActorReminderRequest\x12\x12\n\nactor_type\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tor_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08\x64ue_time\x18\x04 \x01(\t\x12\x0e\n\x06period\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\x12\x0b\n\x03ttl\x18\x07 \x01(\t\"T\n\x1eUnregisterActorReminderRequest\x12\x12\n\nactor_type\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tor_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"f\n\x1aRenameActorReminderRequest\x12\x12\n\nactor_type\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tor_id\x18\x02 \x01(\t\x12\x10\n\x08old_name\x18\x03 \x01(\t\x12\x10\n\x08new_name\x18\x04 \x01(\t\"I\n\x14GetActorStateRequest\x12\x12\n\nactor_type\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tor_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"%\n\x15GetActorStateResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x98\x01\n#ExecuteActorStateTransactionRequest\x12\x12\n\nactor_type\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tor_id\x18\x02 \x01(\t\x12K\n\noperations\x18\x03 \x03(\x0b\x32\x37.dapr.proto.runtime.v1.TransactionalActorStateOperation\"k\n TransactionalActorStateOperation\x12\x15\n\roperationType\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12#\n\x05value\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\"X\n\x12InvokeActorRequest\x12\x12\n\nactor_type\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tor_id\x18\x02 \x01(\t\x12\x0e\n\x06method\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\"#\n\x13InvokeActorResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\xca\x02\n\x13GetMetadataResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x45\n\x13\x61\x63tive_actors_count\x18\x02 \x03(\x0b\x32(.dapr.proto.runtime.v1.ActiveActorsCount\x12J\n\x15registered_components\x18\x03 \x03(\x0b\x32+.dapr.proto.runtime.v1.RegisteredComponents\x12[\n\x11\x65xtended_metadata\x18\x04 \x03(\x0b\x32@.dapr.proto.runtime.v1.GetMetadataResponse.ExtendedMetadataEntry\x1a\x37\n\x15\x45xtendedMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"0\n\x11\x41\x63tiveActorsCount\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"Y\n\x14RegisteredComponents\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x14\n\x0c\x63\x61pabilities\x18\x04 \x03(\t\"0\n\x12SetMetadataRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xbc\x01\n\x17GetConfigurationRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12N\n\x08metadata\x18\x03 \x03(\x0b\x32<.dapr.proto.runtime.v1.GetConfigurationRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"R\n\x18GetConfigurationResponse\x12\x36\n\x05items\x18\x01 \x03(\x0b\x32\'.dapr.proto.common.v1.ConfigurationItem\"\xc8\x01\n\x1dSubscribeConfigurationRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12T\n\x08metadata\x18\x03 \x03(\x0b\x32\x42.dapr.proto.runtime.v1.SubscribeConfigurationRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"A\n\x1fUnsubscribeConfigurationRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"d\n\x1eSubscribeConfigurationResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x05items\x18\x02 \x03(\x0b\x32\'.dapr.proto.common.v1.ConfigurationItem\"?\n UnsubscribeConfigurationResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"f\n\x0eTryLockRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\x12\n\nlock_owner\x18\x03 \x01(\t\x12\x17\n\x0f\x65xpiryInSeconds\x18\x04 \x01(\x05\"\"\n\x0fTryLockResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"L\n\rUnlockRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\x12\n\nlock_owner\x18\x03 \x01(\t\"\xae\x01\n\x0eUnlockResponse\x12<\n\x06status\x18\x01 \x01(\x0e\x32,.dapr.proto.runtime.v1.UnlockResponse.Status\"^\n\x06Status\x12\x0b\n\x07SUCCESS\x10\x00\x12\x17\n\x13LOCK_DOES_NOT_EXIST\x10\x01\x12\x1a\n\x16LOCK_BELONGS_TO_OTHERS\x10\x02\x12\x12\n\x0eINTERNAL_ERROR\x10\x03\x32\xba\x16\n\x04\x44\x61pr\x12\x64\n\rInvokeService\x12+.dapr.proto.runtime.v1.InvokeServiceRequest\x1a$.dapr.proto.common.v1.InvokeResponse\"\x00\x12]\n\x08GetState\x12&.dapr.proto.runtime.v1.GetStateRequest\x1a\'.dapr.proto.runtime.v1.GetStateResponse\"\x00\x12i\n\x0cGetBulkState\x12*.dapr.proto.runtime.v1.GetBulkStateRequest\x1a+.dapr.proto.runtime.v1.GetBulkStateResponse\"\x00\x12N\n\tSaveState\x12\'.dapr.proto.runtime.v1.SaveStateRequest\x1a\x16.google.protobuf.Empty\"\x00\x12i\n\x10QueryStateAlpha1\x12(.dapr.proto.runtime.v1.QueryStateRequest\x1a).dapr.proto.runtime.v1.QueryStateResponse\"\x00\x12R\n\x0b\x44\x65leteState\x12).dapr.proto.runtime.v1.DeleteStateRequest\x1a\x16.google.protobuf.Empty\"\x00\x12Z\n\x0f\x44\x65leteBulkState\x12-.dapr.proto.runtime.v1.DeleteBulkStateRequest\x1a\x16.google.protobuf.Empty\"\x00\x12j\n\x17\x45xecuteStateTransaction\x12\x35.dapr.proto.runtime.v1.ExecuteStateTransactionRequest\x1a\x16.google.protobuf.Empty\"\x00\x12T\n\x0cPublishEvent\x12*.dapr.proto.runtime.v1.PublishEventRequest\x1a\x16.google.protobuf.Empty\"\x00\x12l\n\rInvokeBinding\x12+.dapr.proto.runtime.v1.InvokeBindingRequest\x1a,.dapr.proto.runtime.v1.InvokeBindingResponse\"\x00\x12`\n\tGetSecret\x12\'.dapr.proto.runtime.v1.GetSecretRequest\x1a(.dapr.proto.runtime.v1.GetSecretResponse\"\x00\x12l\n\rGetBulkSecret\x12+.dapr.proto.runtime.v1.GetBulkSecretRequest\x1a,.dapr.proto.runtime.v1.GetBulkSecretResponse\"\x00\x12`\n\x12RegisterActorTimer\x12\x30.dapr.proto.runtime.v1.RegisterActorTimerRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x64\n\x14UnregisterActorTimer\x12\x32.dapr.proto.runtime.v1.UnregisterActorTimerRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x66\n\x15RegisterActorReminder\x12\x33.dapr.proto.runtime.v1.RegisterActorReminderRequest\x1a\x16.google.protobuf.Empty\"\x00\x12j\n\x17UnregisterActorReminder\x12\x35.dapr.proto.runtime.v1.UnregisterActorReminderRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x62\n\x13RenameActorReminder\x12\x31.dapr.proto.runtime.v1.RenameActorReminderRequest\x1a\x16.google.protobuf.Empty\"\x00\x12l\n\rGetActorState\x12+.dapr.proto.runtime.v1.GetActorStateRequest\x1a,.dapr.proto.runtime.v1.GetActorStateResponse\"\x00\x12t\n\x1c\x45xecuteActorStateTransaction\x12:.dapr.proto.runtime.v1.ExecuteActorStateTransactionRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x66\n\x0bInvokeActor\x12).dapr.proto.runtime.v1.InvokeActorRequest\x1a*.dapr.proto.runtime.v1.InvokeActorResponse\"\x00\x12{\n\x16GetConfigurationAlpha1\x12..dapr.proto.runtime.v1.GetConfigurationRequest\x1a/.dapr.proto.runtime.v1.GetConfigurationResponse\"\x00\x12\x8f\x01\n\x1cSubscribeConfigurationAlpha1\x12\x34.dapr.proto.runtime.v1.SubscribeConfigurationRequest\x1a\x35.dapr.proto.runtime.v1.SubscribeConfigurationResponse\"\x00\x30\x01\x12\x93\x01\n\x1eUnsubscribeConfigurationAlpha1\x12\x36.dapr.proto.runtime.v1.UnsubscribeConfigurationRequest\x1a\x37.dapr.proto.runtime.v1.UnsubscribeConfigurationResponse\"\x00\x12`\n\rTryLockAlpha1\x12%.dapr.proto.runtime.v1.TryLockRequest\x1a&.dapr.proto.runtime.v1.TryLockResponse\"\x00\x12]\n\x0cUnlockAlpha1\x12$.dapr.proto.runtime.v1.UnlockRequest\x1a%.dapr.proto.runtime.v1.UnlockResponse\"\x00\x12S\n\x0bGetMetadata\x12\x16.google.protobuf.Empty\x1a*.dapr.proto.runtime.v1.GetMetadataResponse\"\x00\x12R\n\x0bSetMetadata\x12).dapr.proto.runtime.v1.SetMetadataRequest\x1a\x16.google.protobuf.Empty\"\x00\x12<\n\x08Shutdown\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x42i\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\xaa\x02\x1b\x44\x61pr.Client.Autogen.Grpc.v1b\x06proto3')



_INVOKESERVICEREQUEST = DESCRIPTOR.message_types_by_name['InvokeServiceRequest']
_GETSTATEREQUEST = DESCRIPTOR.message_types_by_name['GetStateRequest']
_GETSTATEREQUEST_METADATAENTRY = _GETSTATEREQUEST.nested_types_by_name['MetadataEntry']
_GETBULKSTATEREQUEST = DESCRIPTOR.message_types_by_name['GetBulkStateRequest']
_GETBULKSTATEREQUEST_METADATAENTRY = _GETBULKSTATEREQUEST.nested_types_by_name['MetadataEntry']
_GETBULKSTATERESPONSE = DESCRIPTOR.message_types_by_name['GetBulkStateResponse']
_BULKSTATEITEM = DESCRIPTOR.message_types_by_name['BulkStateItem']
_BULKSTATEITEM_METADATAENTRY = _BULKSTATEITEM.nested_types_by_name['MetadataEntry']
_GETSTATERESPONSE = DESCRIPTOR.message_types_by_name['GetStateResponse']
_GETSTATERESPONSE_METADATAENTRY = _GETSTATERESPONSE.nested_types_by_name['MetadataEntry']
_DELETESTATEREQUEST = DESCRIPTOR.message_types_by_name['DeleteStateRequest']
_DELETESTATEREQUEST_METADATAENTRY = _DELETESTATEREQUEST.nested_types_by_name['MetadataEntry']
_DELETEBULKSTATEREQUEST = DESCRIPTOR.message_types_by_name['DeleteBulkStateRequest']
_SAVESTATEREQUEST = DESCRIPTOR.message_types_by_name['SaveStateRequest']
_QUERYSTATEREQUEST = DESCRIPTOR.message_types_by_name['QueryStateRequest']
_QUERYSTATEREQUEST_METADATAENTRY = _QUERYSTATEREQUEST.nested_types_by_name['MetadataEntry']
_QUERYSTATEITEM = DESCRIPTOR.message_types_by_name['QueryStateItem']
_QUERYSTATERESPONSE = DESCRIPTOR.message_types_by_name['QueryStateResponse']
_QUERYSTATERESPONSE_METADATAENTRY = _QUERYSTATERESPONSE.nested_types_by_name['MetadataEntry']
_PUBLISHEVENTREQUEST = DESCRIPTOR.message_types_by_name['PublishEventRequest']
_PUBLISHEVENTREQUEST_METADATAENTRY = _PUBLISHEVENTREQUEST.nested_types_by_name['MetadataEntry']
_INVOKEBINDINGREQUEST = DESCRIPTOR.message_types_by_name['InvokeBindingRequest']
_INVOKEBINDINGREQUEST_METADATAENTRY = _INVOKEBINDINGREQUEST.nested_types_by_name['MetadataEntry']
_INVOKEBINDINGRESPONSE = DESCRIPTOR.message_types_by_name['InvokeBindingResponse']
_INVOKEBINDINGRESPONSE_METADATAENTRY = _INVOKEBINDINGRESPONSE.nested_types_by_name['MetadataEntry']
_GETSECRETREQUEST = DESCRIPTOR.message_types_by_name['GetSecretRequest']
_GETSECRETREQUEST_METADATAENTRY = _GETSECRETREQUEST.nested_types_by_name['MetadataEntry']
_GETSECRETRESPONSE = DESCRIPTOR.message_types_by_name['GetSecretResponse']
_GETSECRETRESPONSE_DATAENTRY = _GETSECRETRESPONSE.nested_types_by_name['DataEntry']
_GETBULKSECRETREQUEST = DESCRIPTOR.message_types_by_name['GetBulkSecretRequest']
_GETBULKSECRETREQUEST_METADATAENTRY = _GETBULKSECRETREQUEST.nested_types_by_name['MetadataEntry']
_SECRETRESPONSE = DESCRIPTOR.message_types_by_name['SecretResponse']
_SECRETRESPONSE_SECRETSENTRY = _SECRETRESPONSE.nested_types_by_name['SecretsEntry']
_GETBULKSECRETRESPONSE = DESCRIPTOR.message_types_by_name['GetBulkSecretResponse']
_GETBULKSECRETRESPONSE_DATAENTRY = _GETBULKSECRETRESPONSE.nested_types_by_name['DataEntry']
_TRANSACTIONALSTATEOPERATION = DESCRIPTOR.message_types_by_name['TransactionalStateOperation']
_EXECUTESTATETRANSACTIONREQUEST = DESCRIPTOR.message_types_by_name['ExecuteStateTransactionRequest']
_EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY = _EXECUTESTATETRANSACTIONREQUEST.nested_types_by_name['MetadataEntry']
_REGISTERACTORTIMERREQUEST = DESCRIPTOR.message_types_by_name['RegisterActorTimerRequest']
_UNREGISTERACTORTIMERREQUEST = DESCRIPTOR.message_types_by_name['UnregisterActorTimerRequest']
_REGISTERACTORREMINDERREQUEST = DESCRIPTOR.message_types_by_name['RegisterActorReminderRequest']
_UNREGISTERACTORREMINDERREQUEST = DESCRIPTOR.message_types_by_name['UnregisterActorReminderRequest']
_RENAMEACTORREMINDERREQUEST = DESCRIPTOR.message_types_by_name['RenameActorReminderRequest']
_GETACTORSTATEREQUEST = DESCRIPTOR.message_types_by_name['GetActorStateRequest']
_GETACTORSTATERESPONSE = DESCRIPTOR.message_types_by_name['GetActorStateResponse']
_EXECUTEACTORSTATETRANSACTIONREQUEST = DESCRIPTOR.message_types_by_name['ExecuteActorStateTransactionRequest']
_TRANSACTIONALACTORSTATEOPERATION = DESCRIPTOR.message_types_by_name['TransactionalActorStateOperation']
_INVOKEACTORREQUEST = DESCRIPTOR.message_types_by_name['InvokeActorRequest']
_INVOKEACTORRESPONSE = DESCRIPTOR.message_types_by_name['InvokeActorResponse']
_GETMETADATARESPONSE = DESCRIPTOR.message_types_by_name['GetMetadataResponse']
_GETMETADATARESPONSE_EXTENDEDMETADATAENTRY = _GETMETADATARESPONSE.nested_types_by_name['ExtendedMetadataEntry']
_ACTIVEACTORSCOUNT = DESCRIPTOR.message_types_by_name['ActiveActorsCount']
_REGISTEREDCOMPONENTS = DESCRIPTOR.message_types_by_name['RegisteredComponents']
_SETMETADATAREQUEST = DESCRIPTOR.message_types_by_name['SetMetadataRequest']
_GETCONFIGURATIONREQUEST = DESCRIPTOR.message_types_by_name['GetConfigurationRequest']
_GETCONFIGURATIONREQUEST_METADATAENTRY = _GETCONFIGURATIONREQUEST.nested_types_by_name['MetadataEntry']
_GETCONFIGURATIONRESPONSE = DESCRIPTOR.message_types_by_name['GetConfigurationResponse']
_SUBSCRIBECONFIGURATIONREQUEST = DESCRIPTOR.message_types_by_name['SubscribeConfigurationRequest']
_SUBSCRIBECONFIGURATIONREQUEST_METADATAENTRY = _SUBSCRIBECONFIGURATIONREQUEST.nested_types_by_name['MetadataEntry']
_UNSUBSCRIBECONFIGURATIONREQUEST = DESCRIPTOR.message_types_by_name['UnsubscribeConfigurationRequest']
_SUBSCRIBECONFIGURATIONRESPONSE = DESCRIPTOR.message_types_by_name['SubscribeConfigurationResponse']
_UNSUBSCRIBECONFIGURATIONRESPONSE = DESCRIPTOR.message_types_by_name['UnsubscribeConfigurationResponse']
_TRYLOCKREQUEST = DESCRIPTOR.message_types_by_name['TryLockRequest']
_TRYLOCKRESPONSE = DESCRIPTOR.message_types_by_name['TryLockResponse']
_UNLOCKREQUEST = DESCRIPTOR.message_types_by_name['UnlockRequest']
_UNLOCKRESPONSE = DESCRIPTOR.message_types_by_name['UnlockResponse']
_UNLOCKRESPONSE_STATUS = _UNLOCKRESPONSE.enum_types_by_name['Status']
InvokeServiceRequest = _reflection.GeneratedProtocolMessageType('InvokeServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _INVOKESERVICEREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.InvokeServiceRequest)
  })
_sym_db.RegisterMessage(InvokeServiceRequest)

GetStateRequest = _reflection.GeneratedProtocolMessageType('GetStateRequest', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETSTATEREQUEST_METADATAENTRY,
    '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetStateRequest.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _GETSTATEREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetStateRequest)
  })
_sym_db.RegisterMessage(GetStateRequest)
_sym_db.RegisterMessage(GetStateRequest.MetadataEntry)

GetBulkStateRequest = _reflection.GeneratedProtocolMessageType('GetBulkStateRequest', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETBULKSTATEREQUEST_METADATAENTRY,
    '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetBulkStateRequest.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _GETBULKSTATEREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetBulkStateRequest)
  })
_sym_db.RegisterMessage(GetBulkStateRequest)
_sym_db.RegisterMessage(GetBulkStateRequest.MetadataEntry)

GetBulkStateResponse = _reflection.GeneratedProtocolMessageType('GetBulkStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBULKSTATERESPONSE,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetBulkStateResponse)
  })
_sym_db.RegisterMessage(GetBulkStateResponse)

BulkStateItem = _reflection.GeneratedProtocolMessageType('BulkStateItem', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _BULKSTATEITEM_METADATAENTRY,
    '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.BulkStateItem.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _BULKSTATEITEM,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.BulkStateItem)
  })
_sym_db.RegisterMessage(BulkStateItem)
_sym_db.RegisterMessage(BulkStateItem.MetadataEntry)

GetStateResponse = _reflection.GeneratedProtocolMessageType('GetStateResponse', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETSTATERESPONSE_METADATAENTRY,
    '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetStateResponse.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _GETSTATERESPONSE,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetStateResponse)
  })
_sym_db.RegisterMessage(GetStateResponse)
_sym_db.RegisterMessage(GetStateResponse.MetadataEntry)

DeleteStateRequest = _reflection.GeneratedProtocolMessageType('DeleteStateRequest', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _DELETESTATEREQUEST_METADATAENTRY,
    '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.DeleteStateRequest.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _DELETESTATEREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.DeleteStateRequest)
  })
_sym_db.RegisterMessage(DeleteStateRequest)
_sym_db.RegisterMessage(DeleteStateRequest.MetadataEntry)

DeleteBulkStateRequest = _reflection.GeneratedProtocolMessageType('DeleteBulkStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBULKSTATEREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.DeleteBulkStateRequest)
  })
_sym_db.RegisterMessage(DeleteBulkStateRequest)

SaveStateRequest = _reflection.GeneratedProtocolMessageType('SaveStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SAVESTATEREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.SaveStateRequest)
  })
_sym_db.RegisterMessage(SaveStateRequest)

QueryStateRequest = _reflection.GeneratedProtocolMessageType('QueryStateRequest', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _QUERYSTATEREQUEST_METADATAENTRY,
    '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.QueryStateRequest.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _QUERYSTATEREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.QueryStateRequest)
  })
_sym_db.RegisterMessage(QueryStateRequest)
_sym_db.RegisterMessage(QueryStateRequest.MetadataEntry)

QueryStateItem = _reflection.GeneratedProtocolMessageType('QueryStateItem', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSTATEITEM,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.QueryStateItem)
  })
_sym_db.RegisterMessage(QueryStateItem)

QueryStateResponse = _reflection.GeneratedProtocolMessageType('QueryStateResponse', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _QUERYSTATERESPONSE_METADATAENTRY,
    '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.QueryStateResponse.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _QUERYSTATERESPONSE,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.QueryStateResponse)
  })
_sym_db.RegisterMessage(QueryStateResponse)
_sym_db.RegisterMessage(QueryStateResponse.MetadataEntry)

PublishEventRequest = _reflection.GeneratedProtocolMessageType('PublishEventRequest', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _PUBLISHEVENTREQUEST_METADATAENTRY,
    '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.PublishEventRequest.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _PUBLISHEVENTREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.PublishEventRequest)
  })
_sym_db.RegisterMessage(PublishEventRequest)
_sym_db.RegisterMessage(PublishEventRequest.MetadataEntry)

InvokeBindingRequest = _reflection.GeneratedProtocolMessageType('InvokeBindingRequest', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _INVOKEBINDINGREQUEST_METADATAENTRY,
    '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.InvokeBindingRequest.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _INVOKEBINDINGREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.InvokeBindingRequest)
  })
_sym_db.RegisterMessage(InvokeBindingRequest)
_sym_db.RegisterMessage(InvokeBindingRequest.MetadataEntry)

InvokeBindingResponse = _reflection.GeneratedProtocolMessageType('InvokeBindingResponse', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _INVOKEBINDINGRESPONSE_METADATAENTRY,
    '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.InvokeBindingResponse.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _INVOKEBINDINGRESPONSE,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.InvokeBindingResponse)
  })
_sym_db.RegisterMessage(InvokeBindingResponse)
_sym_db.RegisterMessage(InvokeBindingResponse.MetadataEntry)

GetSecretRequest = _reflection.GeneratedProtocolMessageType('GetSecretRequest', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETSECRETREQUEST_METADATAENTRY,
    '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetSecretRequest.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _GETSECRETREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetSecretRequest)
  })
_sym_db.RegisterMessage(GetSecretRequest)
_sym_db.RegisterMessage(GetSecretRequest.MetadataEntry)

GetSecretResponse = _reflection.GeneratedProtocolMessageType('GetSecretResponse', (_message.Message,), {

  'DataEntry' : _reflection.GeneratedProtocolMessageType('DataEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETSECRETRESPONSE_DATAENTRY,
    '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetSecretResponse.DataEntry)
    })
  ,
  'DESCRIPTOR' : _GETSECRETRESPONSE,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetSecretResponse)
  })
_sym_db.RegisterMessage(GetSecretResponse)
_sym_db.RegisterMessage(GetSecretResponse.DataEntry)

GetBulkSecretRequest = _reflection.GeneratedProtocolMessageType('GetBulkSecretRequest', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETBULKSECRETREQUEST_METADATAENTRY,
    '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetBulkSecretRequest.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _GETBULKSECRETREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetBulkSecretRequest)
  })
_sym_db.RegisterMessage(GetBulkSecretRequest)
_sym_db.RegisterMessage(GetBulkSecretRequest.MetadataEntry)

SecretResponse = _reflection.GeneratedProtocolMessageType('SecretResponse', (_message.Message,), {

  'SecretsEntry' : _reflection.GeneratedProtocolMessageType('SecretsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SECRETRESPONSE_SECRETSENTRY,
    '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.SecretResponse.SecretsEntry)
    })
  ,
  'DESCRIPTOR' : _SECRETRESPONSE,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.SecretResponse)
  })
_sym_db.RegisterMessage(SecretResponse)
_sym_db.RegisterMessage(SecretResponse.SecretsEntry)

GetBulkSecretResponse = _reflection.GeneratedProtocolMessageType('GetBulkSecretResponse', (_message.Message,), {

  'DataEntry' : _reflection.GeneratedProtocolMessageType('DataEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETBULKSECRETRESPONSE_DATAENTRY,
    '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetBulkSecretResponse.DataEntry)
    })
  ,
  'DESCRIPTOR' : _GETBULKSECRETRESPONSE,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetBulkSecretResponse)
  })
_sym_db.RegisterMessage(GetBulkSecretResponse)
_sym_db.RegisterMessage(GetBulkSecretResponse.DataEntry)

TransactionalStateOperation = _reflection.GeneratedProtocolMessageType('TransactionalStateOperation', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONALSTATEOPERATION,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.TransactionalStateOperation)
  })
_sym_db.RegisterMessage(TransactionalStateOperation)

ExecuteStateTransactionRequest = _reflection.GeneratedProtocolMessageType('ExecuteStateTransactionRequest', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY,
    '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.ExecuteStateTransactionRequest.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _EXECUTESTATETRANSACTIONREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.ExecuteStateTransactionRequest)
  })
_sym_db.RegisterMessage(ExecuteStateTransactionRequest)
_sym_db.RegisterMessage(ExecuteStateTransactionRequest.MetadataEntry)

RegisterActorTimerRequest = _reflection.GeneratedProtocolMessageType('RegisterActorTimerRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERACTORTIMERREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.RegisterActorTimerRequest)
  })
_sym_db.RegisterMessage(RegisterActorTimerRequest)

UnregisterActorTimerRequest = _reflection.GeneratedProtocolMessageType('UnregisterActorTimerRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNREGISTERACTORTIMERREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.UnregisterActorTimerRequest)
  })
_sym_db.RegisterMessage(UnregisterActorTimerRequest)

RegisterActorReminderRequest = _reflection.GeneratedProtocolMessageType('RegisterActorReminderRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERACTORREMINDERREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.RegisterActorReminderRequest)
  })
_sym_db.RegisterMessage(RegisterActorReminderRequest)

UnregisterActorReminderRequest = _reflection.GeneratedProtocolMessageType('UnregisterActorReminderRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNREGISTERACTORREMINDERREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.UnregisterActorReminderRequest)
  })
_sym_db.RegisterMessage(UnregisterActorReminderRequest)

RenameActorReminderRequest = _reflection.GeneratedProtocolMessageType('RenameActorReminderRequest', (_message.Message,), {
  'DESCRIPTOR' : _RENAMEACTORREMINDERREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.RenameActorReminderRequest)
  })
_sym_db.RegisterMessage(RenameActorReminderRequest)

GetActorStateRequest = _reflection.GeneratedProtocolMessageType('GetActorStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACTORSTATEREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetActorStateRequest)
  })
_sym_db.RegisterMessage(GetActorStateRequest)

GetActorStateResponse = _reflection.GeneratedProtocolMessageType('GetActorStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACTORSTATERESPONSE,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetActorStateResponse)
  })
_sym_db.RegisterMessage(GetActorStateResponse)

ExecuteActorStateTransactionRequest = _reflection.GeneratedProtocolMessageType('ExecuteActorStateTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEACTORSTATETRANSACTIONREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.ExecuteActorStateTransactionRequest)
  })
_sym_db.RegisterMessage(ExecuteActorStateTransactionRequest)

TransactionalActorStateOperation = _reflection.GeneratedProtocolMessageType('TransactionalActorStateOperation', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONALACTORSTATEOPERATION,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.TransactionalActorStateOperation)
  })
_sym_db.RegisterMessage(TransactionalActorStateOperation)

InvokeActorRequest = _reflection.GeneratedProtocolMessageType('InvokeActorRequest', (_message.Message,), {
  'DESCRIPTOR' : _INVOKEACTORREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.InvokeActorRequest)
  })
_sym_db.RegisterMessage(InvokeActorRequest)

InvokeActorResponse = _reflection.GeneratedProtocolMessageType('InvokeActorResponse', (_message.Message,), {
  'DESCRIPTOR' : _INVOKEACTORRESPONSE,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.InvokeActorResponse)
  })
_sym_db.RegisterMessage(InvokeActorResponse)

GetMetadataResponse = _reflection.GeneratedProtocolMessageType('GetMetadataResponse', (_message.Message,), {

  'ExtendedMetadataEntry' : _reflection.GeneratedProtocolMessageType('ExtendedMetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETMETADATARESPONSE_EXTENDEDMETADATAENTRY,
    '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetMetadataResponse.ExtendedMetadataEntry)
    })
  ,
  'DESCRIPTOR' : _GETMETADATARESPONSE,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetMetadataResponse)
  })
_sym_db.RegisterMessage(GetMetadataResponse)
_sym_db.RegisterMessage(GetMetadataResponse.ExtendedMetadataEntry)

ActiveActorsCount = _reflection.GeneratedProtocolMessageType('ActiveActorsCount', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVEACTORSCOUNT,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.ActiveActorsCount)
  })
_sym_db.RegisterMessage(ActiveActorsCount)

RegisteredComponents = _reflection.GeneratedProtocolMessageType('RegisteredComponents', (_message.Message,), {
  'DESCRIPTOR' : _REGISTEREDCOMPONENTS,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.RegisteredComponents)
  })
_sym_db.RegisterMessage(RegisteredComponents)

SetMetadataRequest = _reflection.GeneratedProtocolMessageType('SetMetadataRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETMETADATAREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.SetMetadataRequest)
  })
_sym_db.RegisterMessage(SetMetadataRequest)

GetConfigurationRequest = _reflection.GeneratedProtocolMessageType('GetConfigurationRequest', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETCONFIGURATIONREQUEST_METADATAENTRY,
    '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetConfigurationRequest.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _GETCONFIGURATIONREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetConfigurationRequest)
  })
_sym_db.RegisterMessage(GetConfigurationRequest)
_sym_db.RegisterMessage(GetConfigurationRequest.MetadataEntry)

GetConfigurationResponse = _reflection.GeneratedProtocolMessageType('GetConfigurationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGURATIONRESPONSE,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.GetConfigurationResponse)
  })
_sym_db.RegisterMessage(GetConfigurationResponse)

SubscribeConfigurationRequest = _reflection.GeneratedProtocolMessageType('SubscribeConfigurationRequest', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _SUBSCRIBECONFIGURATIONREQUEST_METADATAENTRY,
    '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.SubscribeConfigurationRequest.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _SUBSCRIBECONFIGURATIONREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.SubscribeConfigurationRequest)
  })
_sym_db.RegisterMessage(SubscribeConfigurationRequest)
_sym_db.RegisterMessage(SubscribeConfigurationRequest.MetadataEntry)

UnsubscribeConfigurationRequest = _reflection.GeneratedProtocolMessageType('UnsubscribeConfigurationRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNSUBSCRIBECONFIGURATIONREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.UnsubscribeConfigurationRequest)
  })
_sym_db.RegisterMessage(UnsubscribeConfigurationRequest)

SubscribeConfigurationResponse = _reflection.GeneratedProtocolMessageType('SubscribeConfigurationResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBECONFIGURATIONRESPONSE,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.SubscribeConfigurationResponse)
  })
_sym_db.RegisterMessage(SubscribeConfigurationResponse)

UnsubscribeConfigurationResponse = _reflection.GeneratedProtocolMessageType('UnsubscribeConfigurationResponse', (_message.Message,), {
  'DESCRIPTOR' : _UNSUBSCRIBECONFIGURATIONRESPONSE,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.UnsubscribeConfigurationResponse)
  })
_sym_db.RegisterMessage(UnsubscribeConfigurationResponse)

TryLockRequest = _reflection.GeneratedProtocolMessageType('TryLockRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRYLOCKREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.TryLockRequest)
  })
_sym_db.RegisterMessage(TryLockRequest)

TryLockResponse = _reflection.GeneratedProtocolMessageType('TryLockResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRYLOCKRESPONSE,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.TryLockResponse)
  })
_sym_db.RegisterMessage(TryLockResponse)

UnlockRequest = _reflection.GeneratedProtocolMessageType('UnlockRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNLOCKREQUEST,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.UnlockRequest)
  })
_sym_db.RegisterMessage(UnlockRequest)

UnlockResponse = _reflection.GeneratedProtocolMessageType('UnlockResponse', (_message.Message,), {
  'DESCRIPTOR' : _UNLOCKRESPONSE,
  '__module__' : 'dapr.proto.runtime.v1.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.proto.runtime.v1.UnlockResponse)
  })
_sym_db.RegisterMessage(UnlockResponse)

_DAPR = DESCRIPTOR.services_by_name['Dapr']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\252\002\033Dapr.Client.Autogen.Grpc.v1'
  _GETSTATEREQUEST_METADATAENTRY._options = None
  _GETSTATEREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _GETBULKSTATEREQUEST_METADATAENTRY._options = None
  _GETBULKSTATEREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _BULKSTATEITEM_METADATAENTRY._options = None
  _BULKSTATEITEM_METADATAENTRY._serialized_options = b'8\001'
  _GETSTATERESPONSE_METADATAENTRY._options = None
  _GETSTATERESPONSE_METADATAENTRY._serialized_options = b'8\001'
  _DELETESTATEREQUEST_METADATAENTRY._options = None
  _DELETESTATEREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _QUERYSTATEREQUEST_METADATAENTRY._options = None
  _QUERYSTATEREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _QUERYSTATERESPONSE_METADATAENTRY._options = None
  _QUERYSTATERESPONSE_METADATAENTRY._serialized_options = b'8\001'
  _PUBLISHEVENTREQUEST_METADATAENTRY._options = None
  _PUBLISHEVENTREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _INVOKEBINDINGREQUEST_METADATAENTRY._options = None
  _INVOKEBINDINGREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _INVOKEBINDINGRESPONSE_METADATAENTRY._options = None
  _INVOKEBINDINGRESPONSE_METADATAENTRY._serialized_options = b'8\001'
  _GETSECRETREQUEST_METADATAENTRY._options = None
  _GETSECRETREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _GETSECRETRESPONSE_DATAENTRY._options = None
  _GETSECRETRESPONSE_DATAENTRY._serialized_options = b'8\001'
  _GETBULKSECRETREQUEST_METADATAENTRY._options = None
  _GETBULKSECRETREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _SECRETRESPONSE_SECRETSENTRY._options = None
  _SECRETRESPONSE_SECRETSENTRY._serialized_options = b'8\001'
  _GETBULKSECRETRESPONSE_DATAENTRY._options = None
  _GETBULKSECRETRESPONSE_DATAENTRY._serialized_options = b'8\001'
  _EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY._options = None
  _EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _GETMETADATARESPONSE_EXTENDEDMETADATAENTRY._options = None
  _GETMETADATARESPONSE_EXTENDEDMETADATAENTRY._serialized_options = b'8\001'
  _GETCONFIGURATIONREQUEST_METADATAENTRY._options = None
  _GETCONFIGURATIONREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _SUBSCRIBECONFIGURATIONREQUEST_METADATAENTRY._options = None
  _SUBSCRIBECONFIGURATIONREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _INVOKESERVICEREQUEST._serialized_start=150
  _INVOKESERVICEREQUEST._serialized_end=238
  _GETSTATEREQUEST._serialized_start=241
  _GETSTATEREQUEST._serialized_end=486
  _GETSTATEREQUEST_METADATAENTRY._serialized_start=439
  _GETSTATEREQUEST_METADATAENTRY._serialized_end=486
  _GETBULKSTATEREQUEST._serialized_start=489
  _GETBULKSTATEREQUEST._serialized_end=690
  _GETBULKSTATEREQUEST_METADATAENTRY._serialized_start=439
  _GETBULKSTATEREQUEST_METADATAENTRY._serialized_end=486
  _GETBULKSTATERESPONSE._serialized_start=692
  _GETBULKSTATERESPONSE._serialized_end=767
  _BULKSTATEITEM._serialized_start=770
  _BULKSTATEITEM._serialized_end=960
  _BULKSTATEITEM_METADATAENTRY._serialized_start=439
  _BULKSTATEITEM_METADATAENTRY._serialized_end=486
  _GETSTATERESPONSE._serialized_start=963
  _GETSTATERESPONSE._serialized_end=1131
  _GETSTATERESPONSE_METADATAENTRY._serialized_start=439
  _GETSTATERESPONSE_METADATAENTRY._serialized_end=486
  _DELETESTATEREQUEST._serialized_start=1134
  _DELETESTATEREQUEST._serialized_end=1406
  _DELETESTATEREQUEST_METADATAENTRY._serialized_start=439
  _DELETESTATEREQUEST_METADATAENTRY._serialized_end=486
  _DELETEBULKSTATEREQUEST._serialized_start=1408
  _DELETEBULKSTATEREQUEST._serialized_end=1501
  _SAVESTATEREQUEST._serialized_start=1503
  _SAVESTATEREQUEST._serialized_end=1590
  _QUERYSTATEREQUEST._serialized_start=1593
  _QUERYSTATEREQUEST._serialized_end=1770
  _QUERYSTATEREQUEST_METADATAENTRY._serialized_start=439
  _QUERYSTATEREQUEST_METADATAENTRY._serialized_end=486
  _QUERYSTATEITEM._serialized_start=1772
  _QUERYSTATEITEM._serialized_end=1844
  _QUERYSTATERESPONSE._serialized_start=1847
  _QUERYSTATERESPONSE._serialized_end=2062
  _QUERYSTATERESPONSE_METADATAENTRY._serialized_start=439
  _QUERYSTATERESPONSE_METADATAENTRY._serialized_end=486
  _PUBLISHEVENTREQUEST._serialized_start=2065
  _PUBLISHEVENTREQUEST._serialized_end=2288
  _PUBLISHEVENTREQUEST_METADATAENTRY._serialized_start=439
  _PUBLISHEVENTREQUEST_METADATAENTRY._serialized_end=486
  _INVOKEBINDINGREQUEST._serialized_start=2291
  _INVOKEBINDINGREQUEST._serialized_end=2486
  _INVOKEBINDINGREQUEST_METADATAENTRY._serialized_start=439
  _INVOKEBINDINGREQUEST_METADATAENTRY._serialized_end=486
  _INVOKEBINDINGRESPONSE._serialized_start=2489
  _INVOKEBINDINGRESPONSE._serialized_end=2653
  _INVOKEBINDINGRESPONSE_METADATAENTRY._serialized_start=439
  _INVOKEBINDINGRESPONSE_METADATAENTRY._serialized_end=486
  _GETSECRETREQUEST._serialized_start=2656
  _GETSECRETREQUEST._serialized_end=2829
  _GETSECRETREQUEST_METADATAENTRY._serialized_start=439
  _GETSECRETREQUEST_METADATAENTRY._serialized_end=486
  _GETSECRETRESPONSE._serialized_start=2832
  _GETSECRETRESPONSE._serialized_end=2962
  _GETSECRETRESPONSE_DATAENTRY._serialized_start=2919
  _GETSECRETRESPONSE_DATAENTRY._serialized_end=2962
  _GETBULKSECRETREQUEST._serialized_start=2965
  _GETBULKSECRETREQUEST._serialized_end=3133
  _GETBULKSECRETREQUEST_METADATAENTRY._serialized_start=439
  _GETBULKSECRETREQUEST_METADATAENTRY._serialized_end=486
  _SECRETRESPONSE._serialized_start=3136
  _SECRETRESPONSE._serialized_end=3269
  _SECRETRESPONSE_SECRETSENTRY._serialized_start=3223
  _SECRETRESPONSE_SECRETSENTRY._serialized_end=3269
  _GETBULKSECRETRESPONSE._serialized_start=3272
  _GETBULKSECRETRESPONSE._serialized_end=3449
  _GETBULKSECRETRESPONSE_DATAENTRY._serialized_start=3367
  _GETBULKSECRETRESPONSE_DATAENTRY._serialized_end=3449
  _TRANSACTIONALSTATEOPERATION._serialized_start=3451
  _TRANSACTIONALSTATEOPERATION._serialized_end=3553
  _EXECUTESTATETRANSACTIONREQUEST._serialized_start=3556
  _EXECUTESTATETRANSACTIONREQUEST._serialized_end=3815
  _EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY._serialized_start=439
  _EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY._serialized_end=486
  _REGISTERACTORTIMERREQUEST._serialized_start=3818
  _REGISTERACTORTIMERREQUEST._serialized_end=3976
  _UNREGISTERACTORTIMERREQUEST._serialized_start=3978
  _UNREGISTERACTORTIMERREQUEST._serialized_end=4059
  _REGISTERACTORREMINDERREQUEST._serialized_start=4062
  _REGISTERACTORREMINDERREQUEST._serialized_end=4205
  _UNREGISTERACTORREMINDERREQUEST._serialized_start=4207
  _UNREGISTERACTORREMINDERREQUEST._serialized_end=4291
  _RENAMEACTORREMINDERREQUEST._serialized_start=4293
  _RENAMEACTORREMINDERREQUEST._serialized_end=4395
  _GETACTORSTATEREQUEST._serialized_start=4397
  _GETACTORSTATEREQUEST._serialized_end=4470
  _GETACTORSTATERESPONSE._serialized_start=4472
  _GETACTORSTATERESPONSE._serialized_end=4509
  _EXECUTEACTORSTATETRANSACTIONREQUEST._serialized_start=4512
  _EXECUTEACTORSTATETRANSACTIONREQUEST._serialized_end=4664
  _TRANSACTIONALACTORSTATEOPERATION._serialized_start=4666
  _TRANSACTIONALACTORSTATEOPERATION._serialized_end=4773
  _INVOKEACTORREQUEST._serialized_start=4775
  _INVOKEACTORREQUEST._serialized_end=4863
  _INVOKEACTORRESPONSE._serialized_start=4865
  _INVOKEACTORRESPONSE._serialized_end=4900
  _GETMETADATARESPONSE._serialized_start=4903
  _GETMETADATARESPONSE._serialized_end=5233
  _GETMETADATARESPONSE_EXTENDEDMETADATAENTRY._serialized_start=5178
  _GETMETADATARESPONSE_EXTENDEDMETADATAENTRY._serialized_end=5233
  _ACTIVEACTORSCOUNT._serialized_start=5235
  _ACTIVEACTORSCOUNT._serialized_end=5283
  _REGISTEREDCOMPONENTS._serialized_start=5285
  _REGISTEREDCOMPONENTS._serialized_end=5374
  _SETMETADATAREQUEST._serialized_start=5376
  _SETMETADATAREQUEST._serialized_end=5424
  _GETCONFIGURATIONREQUEST._serialized_start=5427
  _GETCONFIGURATIONREQUEST._serialized_end=5615
  _GETCONFIGURATIONREQUEST_METADATAENTRY._serialized_start=439
  _GETCONFIGURATIONREQUEST_METADATAENTRY._serialized_end=486
  _GETCONFIGURATIONRESPONSE._serialized_start=5617
  _GETCONFIGURATIONRESPONSE._serialized_end=5699
  _SUBSCRIBECONFIGURATIONREQUEST._serialized_start=5702
  _SUBSCRIBECONFIGURATIONREQUEST._serialized_end=5902
  _SUBSCRIBECONFIGURATIONREQUEST_METADATAENTRY._serialized_start=439
  _SUBSCRIBECONFIGURATIONREQUEST_METADATAENTRY._serialized_end=486
  _UNSUBSCRIBECONFIGURATIONREQUEST._serialized_start=5904
  _UNSUBSCRIBECONFIGURATIONREQUEST._serialized_end=5969
  _SUBSCRIBECONFIGURATIONRESPONSE._serialized_start=5971
  _SUBSCRIBECONFIGURATIONRESPONSE._serialized_end=6071
  _UNSUBSCRIBECONFIGURATIONRESPONSE._serialized_start=6073
  _UNSUBSCRIBECONFIGURATIONRESPONSE._serialized_end=6136
  _TRYLOCKREQUEST._serialized_start=6138
  _TRYLOCKREQUEST._serialized_end=6240
  _TRYLOCKRESPONSE._serialized_start=6242
  _TRYLOCKRESPONSE._serialized_end=6276
  _UNLOCKREQUEST._serialized_start=6278
  _UNLOCKREQUEST._serialized_end=6354
  _UNLOCKRESPONSE._serialized_start=6357
  _UNLOCKRESPONSE._serialized_end=6531
  _UNLOCKRESPONSE_STATUS._serialized_start=6437
  _UNLOCKRESPONSE_STATUS._serialized_end=6531
  _DAPR._serialized_start=6534
  _DAPR._serialized_end=9408
# @@protoc_insertion_point(module_scope)
